---
name: TOML spec conformance bug
about: Bugs relating to the library's TOML spec conformance (or lack thereof).
title: ''
labels: [ "bug", "TOML spec" ]
assignees: marzer

---

<!--
    Replace the HTML/TOML comments below with the requested information.
    Please don't delete this template and roll your own!

    Thanks for contributing!
-->


## The non-conforming TOML snippet
```toml

# your TOML here 

```


## What you expected
<!--
    e.g. a link to, or snippet from, the TOML spec, or some reasonable description thereof
-->


## What you got
<!--
    e.g toml-test output
-->


## Environment
**toml++ version and/or commit hash:**  
<!--
    If you're using the single-header version of the library, the version number is right at the top of the file.
    Otherwise you can find it by opening toml++/impl/version.h; it'll be represented by three defines -
    TOML_LIB_MAJOR, TOML_LIB_MINOR and TOML_LIB_PATCH.
    
    If you're not using any particular release and are instead just living large at HEAD of master, the commit hash
    would be super helpful too, though it's not critical.
    
-->

**Any other useful information:**
<!--
    Anything else you think will help me fix the issue. Since this report is for general spec conformance handling
    you probably don't need to worry about compiler versions, compilation flags, et cetera, though include them if
    you feel they're relevant.
-->
